@@ -23,7 +23,7 @@
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
 //#
-//# $Id$
+//# $Id: VirtualTaQLColumn.cc 21521 2014-12-10 08:06:42Z gervandiepen $
 
 #include <casacore/tables/DataMan/VirtualTaQLColumn.h>
 #include <casacore/tables/Tables/Table.h>
@@ -365,9 +365,13 @@ IPosition VirtualTaQLColumn::getResult (uInt rownr, void* dataPtr)
   IPosition shp;
   switch (itsDataType) {
   case TpBool:
-    itsNode->get (rownr, *static_cast<Array<Bool>*>(dataPtr));
-    shp = static_cast<Array<String>*>(dataPtr)->shape();
-    break;
+    {
+      Array<Bool> arr =itsNode->getArrayBool (rownr);
+      Array<Bool>& out = *static_cast<Array<Bool>*>(dataPtr);
+      out.reference (arr);
+      shp = out.shape();
+      break;
+    }
   case TpUChar:
     {
       Array<Int64> arr = itsNode->getArrayInt (rownr);
@@ -423,12 +427,16 @@ IPosition VirtualTaQLColumn::getResult (uInt rownr, void* dataPtr)
       break;
     }
   case TpDouble:
-    itsNode->get (rownr, *static_cast<Array<Double>*>(dataPtr));
-    shp = static_cast<Array<String>*>(dataPtr)->shape();
-    break;
+    {
+      Array<Double> arr  = itsNode->getArrayDouble (rownr);
+      Array<Double>& out = *static_cast<Array<Double>*>(dataPtr);
+      out.reference (arr);
+      shp = out.shape();
+      break;
+    }
   case TpComplex:
     {
-      Array<Double> arr = itsNode->getArrayDouble (rownr);
+      Array<DComplex> arr = itsNode->getArrayDComplex (rownr);
       Array<Complex>& out = *static_cast<Array<Complex>*>(dataPtr);
       out.resize (arr.shape());
       convertArray (out, arr);
@@ -436,13 +444,21 @@ IPosition VirtualTaQLColumn::getResult (uInt rownr, void* dataPtr)
       break;
     }
   case TpDComplex:
-    itsNode->get (rownr, *static_cast<Array<DComplex>*>(dataPtr));
-    shp = static_cast<Array<String>*>(dataPtr)->shape();
-    break;
+    {
+      Array<DComplex> arr  = itsNode->getArrayDComplex (rownr);
+      Array<DComplex>& out = *static_cast<Array<DComplex>*>(dataPtr);
+      out.reference (arr);
+      shp = out.shape();
+      break;
+    }
   case TpString:
-    itsNode->get (rownr, *static_cast<Array<String>*>(dataPtr));
-    shp = static_cast<Array<String>*>(dataPtr)->shape();
-    break;
+    {
+      Array<String> arr  = itsNode->getArrayString (rownr);
+      Array<String>& out = *static_cast<Array<String>*>(dataPtr);
+      out.reference (arr);
+      shp = out.shape();
+      break;
+    }
   default:
     throw DataManError ("VirtualTaQLColumn::getResult - unknown data type");
   }
