@@ -23,7 +23,7 @@
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
 //#
-//# $Id$
+//# $Id: ExprConeNode.cc 21262 2012-09-07 12:38:36Z gervandiepen $
 
 #include <casacore/tables/TaQL/ExprConeNode.h>
 #include <casacore/tables/Tables/TableError.h>
@@ -74,11 +74,11 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
   switch (funcType()) {
   case TableExprFuncNode::anyconeFUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First ANYCONE argument must have 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
 	throw TableInvExpr("Second ANYCONE argument "
 			   "must have multiple of 3 values");
@@ -105,11 +105,11 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     }
   case TableExprFuncNode::conesFUNC:
     {
-      Array<double> srcArr  = operands_p[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands_p[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First CONES argument must have 2 values");
       }
-      Array<double> coneArr = operands_p[1]->getArrayDouble(id);
+      Array<double> coneArr = operands_p[1]->getArrayDouble(id).array();
       if (coneArr.nelements() != 3) {
 	throw TableInvExpr("Second CONES argument "
 			   "must have multiple of 3 values");
@@ -130,11 +130,11 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     }
   case TableExprFuncNode::anycone3FUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First ANYCONE argument must have 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
 	throw TableInvExpr("Second ANYCONE3 argument "
 			   "must have multiple of 2 values");
@@ -145,7 +145,7 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id);
+	radArr = operands()[2]->getArrayDouble(id).array();
 	nrrad = radArr.nelements();
       } else {
 	radval = operands()[2]->getDouble(id);
@@ -183,12 +183,12 @@ Bool TableExprConeNode::getBool (const TableExprId& id)
     }
   case TableExprFuncNode::cones3FUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First CONES argument "
 			   "must have 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
 	throw TableInvExpr("Second CONES3 argument "
 			   "must have multiple of 2 values");
@@ -219,12 +219,12 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
   switch (funcType()) {
   case TableExprFuncNode::findconeFUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First FINDCONE argument "
 			   "must have 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
 	throw TableInvExpr("Second FINDCONE argument "
 			   "must have multiple of 3 values");
@@ -251,12 +251,12 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
     }
   case TableExprFuncNode::findcone3FUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First FINDCONE argument "
 			   "must have 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
 	throw TableInvExpr("Second FINDCONE3 argument "
 			   "must have multiple of 2 values");
@@ -267,7 +267,7 @@ Int64 TableExprConeNode::getInt (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id);
+	radArr = operands()[2]->getArrayDouble(id).array();
 	nrrad = radArr.nelements();
       } else {
 	radval = operands()[2]->getDouble(id);
@@ -426,17 +426,17 @@ void TableExprConeNodeArray::tryToConst()
 {
 }
 
-Array<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
+MArray<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
 {
   switch (funcType()) {
   case TableExprFuncNode::conesFUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() % 2 != 0) {
 	throw TableInvExpr("First CONES argument "
 			   "must have multiple of 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
 	throw TableInvExpr("Second CONES argument "
 			   "must have multiple of 3 values");
@@ -463,16 +463,16 @@ Array<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
-      return resArr;
+      return MArray<Bool>(resArr);
     }
   case TableExprFuncNode::cones3FUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() != 2) {
 	throw TableInvExpr("First CONES3 argument "
 			   "must have multiple of 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
 	throw TableInvExpr("Second CONES3 argument "
 			   "must have multiple of 2 values");
@@ -483,7 +483,7 @@ Array<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id);
+	radArr = operands()[2]->getArrayDouble(id).array();
 	nrrad = radArr.nelements();
       } else {
 	radval = operands()[2]->getDouble(id);
@@ -520,7 +520,7 @@ Array<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
       if (rad != &radval) {
 	radArr.freeStorage (rad, deleteRad);
       }
-      return resArr;
+      return MArray<Bool>(resArr);
     }
   default:
     throw (TableInvExpr ("TableExprConeNodeArray::getArrayBool, "
@@ -528,17 +528,17 @@ Array<Bool> TableExprConeNodeArray::getArrayBool (const TableExprId& id)
   }
 }
 
-Array<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
+MArray<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
 {
   switch (funcType()) {
   case TableExprFuncNode::findconeFUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() % 2 != 0) {
 	throw TableInvExpr("First FINDCONE argument "
 			   "must have multiple of 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 3 != 0) {
 	throw TableInvExpr("Second FINDCONE argument "
 			   "must have multiple of 3 values");
@@ -575,16 +575,16 @@ Array<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
       }
       srcArr.freeStorage (src, deleteSrc);
       coneArr.freeStorage (cone, deleteCone);
-      return resArr;
+      return MArray<Int64>(resArr);
     }
   case TableExprFuncNode::findcone3FUNC:
     {
-      Array<double> srcArr  = operands()[0]->getArrayDouble(id);
+      Array<double> srcArr  = operands()[0]->getArrayDouble(id).array();
       if (srcArr.nelements() % 2 != 0) {
 	throw TableInvExpr("First FINDCONE argument "
 			   "must have multiple of 2 values");
       }
-      Array<double> coneArr = operands()[1]->getArrayDouble(id);
+      Array<double> coneArr = operands()[1]->getArrayDouble(id).array();
       if (coneArr.nelements() % 2 != 0) {
 	throw TableInvExpr("Second FINDCONE3 argument "
 			   "must have multiple of 2 values");
@@ -595,7 +595,7 @@ Array<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
       const double* rad = 0;
       Array<double> radArr;
       if ( operands()[2]->valueType() == VTArray) {
-	radArr = operands()[2]->getArrayDouble(id);
+	radArr = operands()[2]->getArrayDouble(id).array();
 	nrrad = radArr.nelements();
       } else {
 	radval = operands()[2]->getDouble(id);
@@ -643,7 +643,7 @@ Array<Int64> TableExprConeNodeArray::getArrayInt (const TableExprId& id)
       if (rad != &radval) {
 	radArr.freeStorage (rad, deleteRad);
       }
-      return resArr;
+      return MArray<Int64>(resArr);
     }
   default:
     throw (TableInvExpr ("TableExprConeNodeArray::getArrayDouble, "
