@@ -23,13 +23,12 @@
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
 //#
-//# $Id$
+//# $Id: ExprNodeArray.h 21262 2012-09-07 12:38:36Z gervandiepen $
 
 #ifndef TABLES_EXPRNODEARRAY_H
 #define TABLES_EXPRNODEARRAY_H
 
 //# Includes
-#include <casacore/casa/aips.h>
 #include <casacore/tables/TaQL/ExprNodeRep.h>
 #include <casacore/tables/TaQL/TaQLStyle.h>
 #include <casacore/tables/Tables/Table.h>
@@ -80,17 +79,22 @@ public:
     // The default implementation returns 0.
     virtual TableExprNodeRep* makeConstantScalar();
 
+    // Validate the given index against the array's shape.
+    // Treat a negative as an index from the end (a la python) and replace it.
+    IPosition validateIndex (const IPosition& index,
+                             const ArrayBase& arr) const;
+
     // Get the shape of the array in the given row.
     // This default implementation evaluates the value and returns its shape.
     virtual const IPosition& getShape (const TableExprId& id);
 
     // The default implementation of getArrayDouble does
     // getArrayInt and converts the result.
-    virtual Array<Double> getArrayDouble (const TableExprId& id);
+    virtual MArray<Double> getArrayDouble (const TableExprId& id);
 
     // The default implementation of getArrayDComplex does
     // getArrayDouble and converts the result.
-    virtual Array<DComplex> getArrayDComplex (const TableExprId& id);
+    virtual MArray<DComplex> getArrayDComplex (const TableExprId& id);
 
     // Does a value occur in the set?
     // <group>
@@ -100,18 +104,18 @@ public:
     virtual Bool hasDComplex (const TableExprId& id, const DComplex& value);
     virtual Bool hasString   (const TableExprId& id, const String& value);
     virtual Bool hasDate     (const TableExprId& id, const MVTime& value);
-    virtual Array<Bool> hasArrayBool     (const TableExprId& id,
-					  const Array<Bool>& value);
-    virtual Array<Bool> hasArrayInt      (const TableExprId& id,
-					  const Array<Int64>& value);
-    virtual Array<Bool> hasArrayDouble   (const TableExprId& id,
-					  const Array<Double>& value);
-    virtual Array<Bool> hasArrayDComplex (const TableExprId& id,
-					  const Array<DComplex>& value);
-    virtual Array<Bool> hasArrayString   (const TableExprId& id,
-					  const Array<String>& value);
-    virtual Array<Bool> hasArrayDate     (const TableExprId& id,
-					  const Array<MVTime>& value);
+    virtual MArray<Bool> hasArrayBool     (const TableExprId& id,
+                                           const MArray<Bool>& value);
+    virtual MArray<Bool> hasArrayInt      (const TableExprId& id,
+                                           const MArray<Int64>& value);
+    virtual MArray<Bool> hasArrayDouble   (const TableExprId& id,
+                                           const MArray<Double>& value);
+    virtual MArray<Bool> hasArrayDComplex (const TableExprId& id,
+                                           const MArray<DComplex>& value);
+    virtual MArray<Bool> hasArrayString   (const TableExprId& id,
+                                           const MArray<String>& value);
+    virtual MArray<Bool> hasArrayDate     (const TableExprId& id,
+                                           const MArray<MVTime>& value);
     // </group>
 
     // Get a single element from the array in the given row.
@@ -132,18 +136,18 @@ public:
 
     // Get a slice of the array in the given row.
     // <group>
-    virtual Array<Bool>     getSliceBool     (const TableExprId& id,
-					      const Slicer&);
-    virtual Array<Int64>    getSliceInt      (const TableExprId& id,
-					      const Slicer&);
-    virtual Array<Double>   getSliceDouble   (const TableExprId& id,
-					      const Slicer&);
-    virtual Array<DComplex> getSliceDComplex (const TableExprId& id,
-					      const Slicer&);
-    virtual Array<String>   getSliceString   (const TableExprId& id,
-					      const Slicer&);
-    virtual Array<MVTime>   getSliceDate     (const TableExprId& id,
-					      const Slicer&);
+    virtual MArray<Bool>     getSliceBool     (const TableExprId& id,
+                                                  const Slicer&);
+    virtual MArray<Int64>    getSliceInt      (const TableExprId& id,
+                                                  const Slicer&);
+    virtual MArray<Double>   getSliceDouble   (const TableExprId& id,
+                                                  const Slicer&);
+    virtual MArray<DComplex> getSliceDComplex (const TableExprId& id,
+                                                  const Slicer&);
+    virtual MArray<String>   getSliceString   (const TableExprId& id,
+                                                  const Slicer&);
+    virtual MArray<MVTime>   getSliceDate     (const TableExprId& id,
+                                                  const Slicer&);
     // </group>
 
     // Get a single element for the entire column (used by sort).
@@ -173,9 +177,9 @@ public:
     // </group>
 
     // Make an array with the given shape and fill it with the value.
-    static Array<Int64>    makeArray (const IPosition& shape, Int64 value);
-    static Array<Double>   makeArray (const IPosition& shape, Double value);
-    static Array<DComplex> makeArray (const IPosition& shape,
+    static MArray<Int64>    makeArray (const IPosition& shape, Int64 value);
+    static MArray<Double>   makeArray (const IPosition& shape, Double value);
+    static MArray<DComplex> makeArray (const IPosition& shape,
 				      const DComplex& value);
 
 protected:
@@ -271,8 +275,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Bool getElemBool (const TableExprId& id, const Slicer& index);
-    virtual Array<Bool>  getArrayBool (const TableExprId& id);
-    virtual Array<Bool>  getSliceBool (const TableExprId& id, const Slicer&);
+    virtual MArray<Bool>  getArrayBool (const TableExprId& id);
+    virtual MArray<Bool>  getSliceBool (const TableExprId& id, const Slicer&);
     virtual Array<Bool>  getElemColumnBool (const Vector<uInt>& rownrs,
                                             const Slicer&);
 protected:
@@ -309,8 +313,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Int64 getElemInt (const TableExprId& id, const Slicer& index);
-    virtual Array<Int64> getArrayInt (const TableExprId& id);
-    virtual Array<Int64> getSliceInt (const TableExprId& id,
+    virtual MArray<Int64> getArrayInt (const TableExprId& id);
+    virtual MArray<Int64> getSliceInt (const TableExprId& id,
 					  const Slicer&);
     virtual Array<uChar>  getElemColumnuChar (const Vector<uInt>& rownrs,
                                               const Slicer&);
@@ -348,8 +352,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Int64 getElemInt (const TableExprId& id, const Slicer& index);
-    virtual Array<Int64> getArrayInt (const TableExprId& id);
-    virtual Array<Int64> getSliceInt (const TableExprId& id,
+    virtual MArray<Int64> getArrayInt (const TableExprId& id);
+    virtual MArray<Int64> getSliceInt (const TableExprId& id,
 					  const Slicer&);
     virtual Array<Short>  getElemColumnShort (const Vector<uInt>& rownrs,
                                               const Slicer&);
@@ -387,8 +391,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Int64 getElemInt (const TableExprId& id, const Slicer& index);
-    virtual Array<Int64> getArrayInt (const TableExprId& id);
-    virtual Array<Int64> getSliceInt (const TableExprId& id,
+    virtual MArray<Int64> getArrayInt (const TableExprId& id);
+    virtual MArray<Int64> getSliceInt (const TableExprId& id,
 					  const Slicer&);
     virtual Array<uShort> getElemColumnuShort (const Vector<uInt>& rownrs,
                                                const Slicer&);
@@ -426,8 +430,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Int64 getElemInt (const TableExprId& id, const Slicer& index);
-    virtual Array<Int64> getArrayInt (const TableExprId& id);
-    virtual Array<Int64> getSliceInt (const TableExprId& id,
+    virtual MArray<Int64> getArrayInt (const TableExprId& id);
+    virtual MArray<Int64> getSliceInt (const TableExprId& id,
 					  const Slicer&);
     virtual Array<Int>    getElemColumnInt (const Vector<uInt>& rownrs,
                                             const Slicer&);
@@ -465,8 +469,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Int64 getElemInt (const TableExprId& id, const Slicer& index);
-    virtual Array<Int64> getArrayInt (const TableExprId& id);
-    virtual Array<Int64> getSliceInt (const TableExprId& id,
+    virtual MArray<Int64> getArrayInt (const TableExprId& id);
+    virtual MArray<Int64> getSliceInt (const TableExprId& id,
 					  const Slicer&);
     virtual Array<uInt>   getElemColumnuInt (const Vector<uInt>& rownrs,
                                              const Slicer&);
@@ -504,8 +508,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Double getElemDouble (const TableExprId& id, const Slicer& index);
-    virtual Array<Double> getArrayDouble (const TableExprId& id);
-    virtual Array<Double> getSliceDouble (const TableExprId& id,
+    virtual MArray<Double> getArrayDouble (const TableExprId& id);
+    virtual MArray<Double> getSliceDouble (const TableExprId& id,
 					  const Slicer&);
     virtual Array<Float>  getElemColumnFloat (const Vector<uInt>& rownrs,
                                               const Slicer&);
@@ -543,8 +547,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual Double getElemDouble (const TableExprId& id, const Slicer& index);
-    virtual Array<Double> getArrayDouble (const TableExprId& id);
-    virtual Array<Double> getSliceDouble (const TableExprId& id,
+    virtual MArray<Double> getArrayDouble (const TableExprId& id);
+    virtual MArray<Double> getSliceDouble (const TableExprId& id,
 					  const Slicer&);
     virtual Array<Double> getElemColumnDouble (const Vector<uInt>& rownrs,
                                                const Slicer&);
@@ -582,8 +586,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual DComplex getElemDComplex (const TableExprId& id, const Slicer& index);
-    virtual Array<DComplex> getArrayDComplex (const TableExprId& id);
-    virtual Array<DComplex> getSliceDComplex (const TableExprId& id,
+    virtual MArray<DComplex> getArrayDComplex (const TableExprId& id);
+    virtual MArray<DComplex> getSliceDComplex (const TableExprId& id,
 					      const Slicer&);
     virtual Array<Complex>  getElemColumnComplex (const Vector<uInt>& rownrs,
                                                   const Slicer&);
@@ -621,8 +625,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual DComplex getElemDComplex (const TableExprId& id, const Slicer& index);
-    virtual Array<DComplex> getArrayDComplex (const TableExprId& id);
-    virtual Array<DComplex> getSliceDComplex (const TableExprId& id,
+    virtual MArray<DComplex> getArrayDComplex (const TableExprId& id);
+    virtual MArray<DComplex> getSliceDComplex (const TableExprId& id,
 					      const Slicer&);
     virtual Array<DComplex> getElemColumnDComplex (const Vector<uInt>& rownrs,
                                                    const Slicer&);
@@ -660,8 +664,8 @@ public:
     virtual void applySelection (const Vector<uInt>& rownrs);
 
     virtual String getElemString (const TableExprId& id, const Slicer& index);
-    virtual Array<String> getArrayString (const TableExprId& id);
-    virtual Array<String> getSliceString (const TableExprId& id,
+    virtual MArray<String> getArrayString (const TableExprId& id);
+    virtual MArray<String> getSliceString (const TableExprId& id,
 					  const Slicer&);
     virtual Array<String> getElemColumnString (const Vector<uInt>& rownrs,
                                                const Slicer&);
@@ -795,12 +799,12 @@ public:
     String   getString   (const TableExprId& id);
     MVTime   getDate     (const TableExprId& id);
 
-    Array<Bool>     getArrayBool     (const TableExprId& id);
-    Array<Int64>    getArrayInt      (const TableExprId& id);
-    Array<Double>   getArrayDouble   (const TableExprId& id);
-    Array<DComplex> getArrayDComplex (const TableExprId& id);
-    Array<String>   getArrayString   (const TableExprId& id);
-    Array<MVTime>   getArrayDate     (const TableExprId& id);
+    MArray<Bool>     getArrayBool     (const TableExprId& id);
+    MArray<Int64>    getArrayInt      (const TableExprId& id);
+    MArray<Double>   getArrayDouble   (const TableExprId& id);
+    MArray<DComplex> getArrayDComplex (const TableExprId& id);
+    MArray<String>   getArrayString   (const TableExprId& id);
+    MArray<MVTime>   getArrayDate     (const TableExprId& id);
 
     // Get the data type of this column (if possible).
     // It returns with a False status when the index is not constant
