@@ -361,29 +361,19 @@ public:
     // defined, it will be defined implicitly.
     void put (uInt rownr, const Array<T>& array);
 
-    // Copy the value of a cell of that column to a cell of this column.
-    // The data types of both columns must be the same, otherwise an
-    // exception is thrown.
-    // <group>
-    // Use the same row numbers for both cells.
-    void put (uInt rownr, const ArrayColumn<T>& that)
-	{ put (rownr, that, rownr); }
-    // Use possibly different row numbers for that (i.e. input) and
-    // and this (i.e. output) cell.
-    void put (uInt thisRownr, const ArrayColumn<T>& that, uInt thatRownr);
-    // </group>
-
     // Copy the value of a cell of that column to a cell of this column.
     // This function uses a generic TableColumn object as input.
     // The data types of both columns must be the same, otherwise an
     // exception is thrown.
     // <group>
     // Use the same row numbers for both cells.
-    void put (uInt rownr, const TableColumn& that)
-	{ put (rownr, that, rownr); }
+    void put (uInt rownr, const TableColumn& that,
+              Bool preserveTileShape=False)
+      { put (rownr, that, rownr, preserveTileShape); }
     // Use possibly different row numbers for that (i.e. input) and
     // and this (i.e. output) cell.
-    void put (uInt thisRownr, const TableColumn& that, uInt thatRownr);
+    void put (uInt thisRownr, const TableColumn& that, uInt thatRownr,
+              Bool preserveTileShape=False);
     // </group>
 
     // Put into a slice of an N-dimensional array in a particular cell.
@@ -480,6 +470,9 @@ private:
     void checkShape (const IPosition& shp,
                      Array<T>& arr, Bool resize,
                      const String& where) const;
+    void checkShape (const IPosition& shp,
+                     Array<T>& arr, Bool resize,
+                     const char * where) const;
 
 protected:
     // A common function used by all functions that can get or put irregular
